==> touhoulittlemaid-fabric-1.20.1-0.1.7.3-forge1.3.8-sources.jar: com/github/tartaricacid/touhoulittlemaid/client/renderer/tileentity/PicnicBasketRender.java <==
package com.github.tartaricacid.touhoulittlemaid.client.renderer.tileentity;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.client.model.EntityPlaceholderModel;
import com.github.tartaricacid.touhoulittlemaid.client.model.bedrock.SimpleBedrockModel;
import com.github.tartaricacid.touhoulittlemaid.client.resource.BedrockModelLoader;
import net.minecraft.class_1297;
import net.minecraft.class_1799;
import net.minecraft.class_1921;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_5599;
import net.minecraft.class_756;
import net.minecraft.class_7833;
import net.minecraft.class_811;
import net.minecraft.class_824;

public class PicnicBasketRender extends class_756 {
    private static final class_2960 TEXTURE = new class_2960(TouhouLittleMaid.MOD_ID, "textures/bedrock/block/picnic_basket.png");
    private static final class_2960 GUI_TEXTURE = new class_2960(TouhouLittleMaid.MOD_ID, "textures/item/picnic_basket.png");
    private static final EntityPlaceholderModel GUI_MODEL = new EntityPlaceholderModel();
    private final SimpleBedrockModel<class_1297> model;

    public PicnicBasketRender(class_824 dispatcher, class_5599 modelSet) {
        super(dispatcher, modelSet);
        this.model = BedrockModelLoader.getModel(BedrockModelLoader.PICNIC_BASKET);
    }

    @Override
    public void method_3166(class_1799 pStack, class_811 displayContext, class_4587 poseStack, class_4597 buffer, int packedLight, int packedOverlay) {
        if (displayContext == class_811.field_4317) {
            poseStack.method_22903();
            poseStack.method_22904(0.5, 1.5, 0.5);
            poseStack.method_22907(class_7833.field_40717.rotationDegrees(180));
            GUI_MODEL.method_2828(poseStack, buffer.getBuffer(class_1921.method_23578(GUI_TEXTURE)), packedLight, packedOverlay, 1.0F, 1.0F, 1.0F, 1.0F);
            poseStack.method_22909();
        } else if (model != null) {
            poseStack.method_22903();
            poseStack.method_22904(0.5, 1.5, 0.5);
            poseStack.method_22907(class_7833.field_40717.rotationDegrees(180));
            class_1921 renderType = class_1921.method_23578(TEXTURE);
            model.method_2828(poseStack, buffer.getBuffer(renderType), packedLight, packedOverlay, 1, 1, 1, 1);
            poseStack.method_22909();
        }
    }
}

==> touhoulittlemaid-fabric-1.20.1-0.4.2-forge1.4.5-sources.jar: com/github/tartaricacid/touhoulittlemaid/client/renderer/tileentity/PicnicBasketRender.java <==
package com.github.tartaricacid.touhoulittlemaid.client.renderer.tileentity;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.client.model.EntityPlaceholderModel;
import com.github.tartaricacid.touhoulittlemaid.client.model.bedrock.SimpleBedrockModel;
import com.github.tartaricacid.touhoulittlemaid.client.resource.BedrockModelLoader;
import com.google.common.base.Suppliers;
import java.util.function.Supplier;
import net.minecraft.class_1297;
import net.minecraft.class_1799;
import net.minecraft.class_1921;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_5599;
import net.minecraft.class_756;
import net.minecraft.class_7833;
import net.minecraft.class_811;
import net.minecraft.class_824;

public class PicnicBasketRender extends class_756 {
    private static final class_2960 TEXTURE = new class_2960(TouhouLittleMaid.MOD_ID, "textures/bedrock/block/picnic_basket.png");
    private static final class_2960 GUI_TEXTURE = new class_2960(TouhouLittleMaid.MOD_ID, "textures/item/picnic_basket.png");
    private static final EntityPlaceholderModel GUI_MODEL = new EntityPlaceholderModel();
    private final SimpleBedrockModel<class_1297> model;

    public static final Supplier<PicnicBasketRender> INSTANCE = Suppliers.memoize(() -> {
        class_310 minecraft = class_310.method_1551();
        return new PicnicBasketRender(minecraft.method_31975(), minecraft.method_31974());
    });

    public PicnicBasketRender(class_824 dispatcher, class_5599 modelSet) {
        super(dispatcher, modelSet);
        this.model = BedrockModelLoader.getModel(BedrockModelLoader.PICNIC_BASKET);
    }

    @Override
    public void method_3166(class_1799 pStack, class_811 displayContext, class_4587 poseStack, class_4597 buffer, int packedLight, int packedOverlay) {
        if (displayContext == class_811.field_4317) {
            poseStack.method_22903();
            poseStack.method_22904(0.5, 1.5, 0.5);
            poseStack.method_22907(class_7833.field_40717.rotationDegrees(180));
            GUI_MODEL.method_2828(poseStack, buffer.getBuffer(class_1921.method_23578(GUI_TEXTURE)), packedLight, packedOverlay, 1.0F, 1.0F, 1.0F, 1.0F);
            poseStack.method_22909();
        } else if (model != null) {
            poseStack.method_22903();
            poseStack.method_22904(0.5, 1.5, 0.5);
            poseStack.method_22907(class_7833.field_40717.rotationDegrees(180));
            class_1921 renderType = class_1921.method_23578(TEXTURE);
            model.method_2828(poseStack, buffer.getBuffer(renderType), packedLight, packedOverlay, 1, 1, 1, 1);
            poseStack.method_22909();
        }
    }
}
